@@ -649,10 +649,14 @@ dracut -f /boot/initramfs-$KERNEL_VERSION.img $KERNEL_VERSION
       bpf "%%post\n";
       bpf "\
 # Ensure the installation is up-to-date.
-# This makes Fedora >= 33 unbootable, see:
+dnf -y --best upgrade
+# This required otherwise the kernel will not be bootable, see
 # https://bugzilla.redhat.com/show_bug.cgi?id=1911177
-#dnf -y --best upgrade
-";
+# https://bugzilla.redhat.com/show_bug.cgi?id=1945835#c24
+grub2-mkconfig -o %s
+" (quote
+     (if needs_uefi os arch then "/etc/grub2-efi.cfg"
+      else "/etc/grub2.cfg"));
 
       let needs_regenerate_dracut = ref false in
       if arch = X86_64 then (
@@ -879,8 +883,11 @@ and make_boot_media os arch =
      (* This is probably the last CentOS 8 release. *)
      Location "https://vault.centos.org/8.5.2111/BaseOS/x86_64/kickstart/"
 
+  | CentOSStream 8, X86_64 ->
+     Location (sprintf "http://mirror.centos.org/centos/8-stream/BaseOS/x86_64/os")
+
   | CentOSStream ver, X86_64 ->
-     Location (sprintf "http://mirror.centos.org/centos/%d-stream/BaseOS/x86_64/os" ver)
+     Location (sprintf "http://mirror.stream.centos.org/%d-stream/BaseOS/x86_64/os" ver)
 
   | Debian (_, dist), arch ->
      Location (sprintf "http://deb.debian.org/debian/dists/%s/main/installer-%s"
